@@ -2,22 +2,21 @@
 #
 # ripple.R
 #
-# copyright (c) 2001-8, Karl W Broman
-# last modified Oct, 2008
+# copyright (c) 2001-9, Karl W Broman
+# last modified May, 2009
 # first written Oct, 2001
 #
 #     This program is free software; you can redistribute it and/or
-#     modify it under the terms of the GNU General Public License, as
-#     published by the Free Software Foundation; either version 2 of
-#     the License, or (at your option) any later version. 
+#     modify it under the terms of the GNU General Public License,
+#     version 3, as published by the Free Software Foundation.
 # 
 #     This program is distributed in the hope that it will be useful,
 #     but without any warranty; without even the implied warranty of
-#     merchantability or fitness for a particular purpose.  See the
-#     GNU General Public License for more details.
+#     merchantability or fitness for a particular purpose.  See the GNU
+#     General Public License, version 3, for more details.
 # 
-#     A copy of the GNU General Public License is available at
-#     http://www.r-project.org/Licenses/
+#     A copy of the GNU General Public License, version 3, is available
+#     at http://www.r-project.org/Licenses/GPL-3
 # 
 # Part of the R/qtl package
 # Contains: ripple, summary.ripple, print.summary.ripple
@@ -35,14 +34,22 @@
 ripple <-
 function(cross, chr, window=4, method=c("countxo","likelihood"),
          error.prob=0.0001, map.function=c("haldane","kosambi","c-f","morgan"),
-         maxit=4000, tol=1e-4, sex.sp=TRUE, verbose=TRUE)
+         maxit=4000, tol=1e-6, sex.sp=TRUE, verbose=TRUE)
 {
   if(!any(class(cross) == "cross")) 
     stop("Input should have class \"cross\".")
 
   # pull out relevant chromosome
-  if(length(chr) > 1)
-    stop("ripple only works for one chromosome at a time.")
+  if(missing(chr)) {
+    chr <- names(cross$geno)[1]
+    warning("chr argument not provided; assuming you want chr ", chr)
+  }
+  else {
+    if(length(chr) > 1)
+      stop("ripple only works for one chromosome at a time.")
+    if(!testchr(chr, names(cross$geno)))
+      stop("Chr ", chr, "not found.")
+  }
   cross <- subset(cross,chr=chr)
   chr.name <- names(cross$geno)[1]
 
@@ -139,6 +146,8 @@ function(cross, chr, window=4, method=c("countxo","likelihood"),
     }
     else if(type == "bc" || type=="riself" || type=="risib" || type=="dh") func <- "R_ripple_bc"
     else if(type == "4way") func <- "R_ripple_4way"
+    else if(type=="ri4self" || type=="ri8self" || type=="ri4sib" || type=="ri8sib")
+      func <- "R_ripple_ril48"
     else 
       stop("ripple not available for cross ", type)
 
