@@ -3,7 +3,7 @@
 # scanone.R
 #
 # copyright (c) 2001-9, Karl W Broman
-# last modified Sep, 2009
+# last modified Dec, 2009
 # first written Feb, 2001
 #
 #     This program is free software; you can redistribute it and/or
@@ -47,9 +47,16 @@ function(cross, chr, pheno.col=1, model=c("normal","binary","2part","np"),
   method <- match.arg(method)
   use <- match.arg(use)
 
+  # in RIL, treat X chromomse like an autosome
+  chrtype <- sapply(cross$geno, class)
+  if(any(chrtype=="X") && (class(cross)[1] == "risib" || class(cross)[1] == "riself")) 
+    for(i in which(chrtype=="X")) class(cross$geno[[i]]) <- "A"
+
   if(!missing(n.perm) && n.perm > 0 && n.cluster > 1 && suppressWarnings(require(snow,quietly=TRUE))) {
     cat(" -Running permutations via a cluster of", n.cluster, "nodes.\n")
     cl <- makeCluster(n.cluster)
+    clusterStopped <- FALSE
+    on.exit(if(!clusterStopped) stopCluster(cl))
     clusterSetupRNG(cl)
     clusterEvalQ(cl, require(qtl, quietly=TRUE))
     n.perm <- ceiling(n.perm/n.cluster)
@@ -59,6 +66,7 @@ function(cross, chr, pheno.col=1, model=c("normal","binary","2part","np"),
                          start, maxit, tol, n.perm, perm.Xsp, perm.strata, verbose=FALSE,
                          batchsize, n.cluster=0)
     stopCluster(cl)
+    clusterStopped <- TRUE
     for(j in 2:length(operm))
       operm[[1]] <- c(operm[[1]], operm[[j]])
     return(operm[[1]])
@@ -160,7 +168,7 @@ function(cross, chr, pheno.col=1, model=c("normal","binary","2part","np"),
 
       temp <- scanone(subset(cross, ind=upat[[i]]), chr=chr, pheno.col=batches[[i]], model=model,
                       method=method, addcovar=tempac, intcovar=tempic,
-                      weights=weights, use=use, upper=upper, ties.random=ties.random,
+                      weights=weights, use="complete.obs", upper=upper, ties.random=ties.random,
                       start=start, maxit=maxit, tol=tol, n.perm=n.perm, perm.Xsp=perm.Xsp,
                       perm.strata=perm.strata, verbose=verbose, batchsize=batchsize,
                       n.cluster=n.cluster)
